@@ -1,8 +1,9 @@
 import unittest
 from unittest import mock
 from vetmanager.domain import FakeUrl
-from vetmanager.client \
-    import VetmanagerClient, ExecutionException, WrongAuthentificationException
+from vetmanager.client import \
+    Token, TokenCredentials, WrongAuthenticationException, \
+    CachedToken, FakeToken
 
 
 class MockResponse:
@@ -19,7 +20,12 @@ class TestClient(unittest.TestCase):
     @mock.patch('vetmanager.client.requests.post')
     def test_vetmanager_client_auth_success(self, mock):
         url = FakeUrl()
-        client = VetmanagerClient('test_app', url)
+        credentials = TokenCredentials(
+            login='login',
+            password='password',
+            app_name='myapp'
+        )
+        token = Token(credentials=credentials, url=url)
         mock.return_value = MockResponse({
             "status": 200,
             "title": "Authorization completed.",
@@ -30,31 +36,46 @@ class TestClient(unittest.TestCase):
                 'user_id': 1,
             }
         }, 200)
-        self.assertEqual(client.token('login', 'password'), 'test_token')
+        self.assertEqual(str(token), 'test_token')
 
     @mock.patch('vetmanager.client.requests.post')
     def test_vetmanager_client_auth_wrong_password(self, mock):
         url = FakeUrl()
-        client = VetmanagerClient('test_app', url)
+        credentials = TokenCredentials(
+            login='login',
+            password='password',
+            app_name='myapp'
+        )
+        token = Token(credentials=credentials, url=url)
         mock.return_value = MockResponse({
             "status": 401,
             "title":  "Wrong authentification.",
             "detail": "Error Message"
         }, 401)
-        with self.assertRaises(WrongAuthentificationException):
-            client.token('login', 'password')
+        with self.assertRaises(WrongAuthenticationException):
+            str(token)
 
     @mock.patch('vetmanager.client.requests.post')
     def test_vetmanager_client_auth_execution_problem(self, mock):
         url = FakeUrl()
-        client = VetmanagerClient('test_app', url)
+        credentials = TokenCredentials(
+            login='login',
+            password='password',
+            app_name='myapp'
+        )
+        token = Token(credentials=credentials, url=url)
         mock.return_value = MockResponse({
             "status": 500,
             "title":  "Wrong authentification.",
             "detail": "Error Message"
         }, 500)
-        with self.assertRaises(ExecutionException):
-            client.token('login', 'password')
+        with self.assertRaises(Exception):
+            str(token)
+
+    def test_cached_token(self):
+        cached = CachedToken(FakeToken())
+        self.assertEqual(str(cached), 'token1')
+        self.assertEqual(str(cached), 'token1')
 
 
 if __name__ == '__main__':
